
From: Dominik Brodowski <linux@dominikbrodowski.net>

From: Adrian Bunk <bunk@stusta.de>

This patch contains the following cleanups:
- make needlessly global code static
- remove the following unneeded EXPORT_SYMBOL's:
  - ds.c: pcmcia_report_error
  - ds.c: pcmcia_bus_type

Signed-off-by: Adrian Bunk <bunk@stusta.de>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/drivers/pcmcia/ds.c             |   10 +++++-----
 25-akpm/drivers/pcmcia/rsrc_nonstatic.c |    6 +++---
 25-akpm/include/pcmcia/cs.h             |    1 -
 25-akpm/include/pcmcia/ds.h             |    2 --
 4 files changed, 8 insertions(+), 11 deletions(-)

diff -puN drivers/pcmcia/ds.c~pcmcia-cleanups drivers/pcmcia/ds.c
--- 25/drivers/pcmcia/ds.c~pcmcia-cleanups	2005-03-02 18:07:00.000000000 -0800
+++ 25-akpm/drivers/pcmcia/ds.c	2005-03-02 18:07:00.000000000 -0800
@@ -60,7 +60,7 @@ MODULE_DESCRIPTION("PCMCIA Driver Servic
 MODULE_LICENSE("GPL");
 
 #ifdef DEBUG
-int ds_pc_debug;
+static int ds_pc_debug;
 
 module_param_named(pc_debug, ds_pc_debug, int, 0644);
 
@@ -108,6 +108,8 @@ struct pcmcia_bus_socket {
 };
 static spinlock_t pcmcia_dev_list_lock;
 
+static struct bus_type pcmcia_bus_type;
+
 #define DS_SOCKET_PRESENT		0x01
 #define DS_SOCKET_BUSY			0x02
 #define DS_SOCKET_REMOVAL_PENDING	0x10
@@ -218,7 +220,7 @@ static const lookup_t service_table[] = 
 };
 
 
-int pcmcia_report_error(client_handle_t handle, error_info_t *err)
+static int pcmcia_report_error(client_handle_t handle, error_info_t *err)
 {
 	int i;
 	char *serv;
@@ -248,7 +250,6 @@ int pcmcia_report_error(client_handle_t 
 
 	return CS_SUCCESS;
 } /* report_error */
-EXPORT_SYMBOL(pcmcia_report_error);
 
 /* end of code which was in cs.c before */
 
@@ -1898,13 +1899,12 @@ static struct class_interface pcmcia_bus
 };
 
 
-struct bus_type pcmcia_bus_type = {
+static struct bus_type pcmcia_bus_type = {
 	.name = "pcmcia",
 	.hotplug = pcmcia_bus_hotplug,
 	.match = pcmcia_bus_match,
 	.dev_attrs = pcmcia_dev_attrs,
 };
-EXPORT_SYMBOL(pcmcia_bus_type);
 
 
 static int __init init_pcmcia_bus(void)
diff -puN drivers/pcmcia/rsrc_nonstatic.c~pcmcia-cleanups drivers/pcmcia/rsrc_nonstatic.c
--- 25/drivers/pcmcia/rsrc_nonstatic.c~pcmcia-cleanups	2005-03-02 18:07:00.000000000 -0800
+++ 25-akpm/drivers/pcmcia/rsrc_nonstatic.c	2005-03-02 18:07:00.000000000 -0800
@@ -606,7 +606,7 @@ static int nonstatic_adjust_io_region(st
 
 ======================================================================*/
 
-struct resource *nonstatic_find_io_region(unsigned long base, int num,
+static struct resource *nonstatic_find_io_region(unsigned long base, int num,
 		   unsigned long align, struct pcmcia_socket *s)
 {
 	struct resource *res = make_resource(0, num, IORESOURCE_IO, s->dev.class_id);
@@ -640,8 +640,8 @@ struct resource *nonstatic_find_io_regio
 	return res;
 }
 
-struct resource * nonstatic_find_mem_region(u_long base, u_long num, u_long align,
-				 int low, struct pcmcia_socket *s)
+static struct resource * nonstatic_find_mem_region(u_long base, u_long num,
+		u_long align, int low, struct pcmcia_socket *s)
 {
 	struct resource *res = make_resource(0, num, IORESOURCE_MEM, s->dev.class_id);
 	struct socket_data *s_data = s->resource_data;
diff -puN include/pcmcia/cs.h~pcmcia-cleanups include/pcmcia/cs.h
--- 25/include/pcmcia/cs.h~pcmcia-cleanups	2005-03-02 18:07:00.000000000 -0800
+++ 25-akpm/include/pcmcia/cs.h	2005-03-02 18:07:00.000000000 -0800
@@ -417,7 +417,6 @@ int pcmcia_suspend_card(struct pcmcia_so
 int pcmcia_resume_card(struct pcmcia_socket *skt);
 int pcmcia_eject_card(struct pcmcia_socket *skt);
 int pcmcia_insert_card(struct pcmcia_socket *skt);
-int pcmcia_report_error(client_handle_t handle, error_info_t *err);
 
 struct pcmcia_socket * pcmcia_get_socket(struct pcmcia_socket *skt);
 void pcmcia_put_socket(struct pcmcia_socket *skt);
diff -puN include/pcmcia/ds.h~pcmcia-cleanups include/pcmcia/ds.h
--- 25/include/pcmcia/ds.h~pcmcia-cleanups	2005-03-02 18:07:00.000000000 -0800
+++ 25-akpm/include/pcmcia/ds.h	2005-03-02 18:07:00.000000000 -0800
@@ -131,8 +131,6 @@ typedef struct dev_link_t {
 
 struct pcmcia_socket;
 
-extern struct bus_type pcmcia_bus_type;
-
 struct pcmcia_driver {
 	dev_link_t		*(*attach)(void);
 	void			(*detach)(dev_link_t *);
_
